# print\_clear

A tiny CLI tool used to print strings without ambiguity.

It does so by printing out its argument with the numbers colored.

## Example

<style>makered{color:red;}</style>

For example running `print-clear ablab1abOab0` will produce:
ablab<makered>1</makered>abOab<makered>0</makered>
